@@ -34,9 +34,9 @@
 // ----------------------------------------------------------------------------
 // KDE Headers
 
-#include <klocale.h>
-#include <kmessagebox.h>
-#include <kconfig.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
+#include <tdeconfig.h>
 #include <kdebug.h>
 #include <kdialogbase.h>
 #include <tqvbox.h>
@@ -233,7 +233,7 @@ bool MyMoneyStatementReader::import(const MyMoneyStatement& s, TQStringList& mes
     try {
       m_account = MyMoneyFile::instance()->account(s.m_accountId);
     } catch(MyMoneyException* e) {
-      qDebug("Received reference '%s' to unknown account in statement", s.m_accountId.data());
+      tqDebug("Received reference '%s' to unknown account in statement", s.m_accountId.data());
       delete e;
     }
   }
@@ -284,7 +284,7 @@ bool MyMoneyStatementReader::import(const MyMoneyStatement& s, TQStringList& mes
     try {
       MyMoneyFile::instance()->modifyAccount(m_account);
     } catch(MyMoneyException* e) {
-      qDebug("Updating account in MyMoneyStatementReader::startImport failed");
+      tqDebug("Updating account in MyMoneyStatementReader::startImport failed");
       delete e;
     }
   }
@@ -295,7 +295,7 @@ bool MyMoneyStatementReader::import(const MyMoneyStatement& s, TQStringList& mes
   else if(s.m_listTransactions.count() == 0)
     messages += i18n("Importing statement without transactions");
 
-  qDebug("Importing statement for '%s'", m_account.name().data());
+  tqDebug("Importing statement for '%s'", m_account.name().data());
 
   //
   // Process the securities
@@ -318,7 +318,7 @@ bool MyMoneyStatementReader::import(const MyMoneyStatement& s, TQStringList& mes
   if ( !m_userAbort )
   {
     try {
-      qDebug("Processing transactions (%s)", m_account.name().data());
+      tqDebug("Processing transactions (%s)", m_account.name().data());
       signalProgress(0, s.m_listTransactions.count(), "Importing Statement ...");
       int progress = 0;
       TQValueList<MyMoneyStatement::Transaction>::const_iterator it_t = s.m_listTransactions.begin();
@@ -328,13 +328,13 @@ bool MyMoneyStatementReader::import(const MyMoneyStatement& s, TQStringList& mes
         signalProgress(++progress, 0);
         ++it_t;
       }
-      qDebug("Processing transactions done (%s)", m_account.name().data());
+      tqDebug("Processing transactions done (%s)", m_account.name().data());
 
     } catch(MyMoneyException* e) {
       if(e->what() == "USERABORT")
         m_userAbort = true;
       else
-        qDebug("Caught exception from processTransactionEntry() not caused by USERABORT: %s", e->what().data());
+        tqDebug("Caught exception from processTransactionEntry() not caused by USERABORT: %s", e->what().data());
       delete e;
     }
     signalProgress(-1, -1);
@@ -365,7 +365,7 @@ bool MyMoneyStatementReader::import(const MyMoneyStatement& s, TQStringList& mes
       if(e->what() == "USERABORT")
         m_userAbort = true;
       else
-        qDebug("Caught exception from processPriceEntry() not caused by USERABORT: %s", e->what().data());
+        tqDebug("Caught exception from processPriceEntry() not caused by USERABORT: %s", e->what().data());
       delete e;
     }
     signalProgress(-1, -1);
@@ -401,7 +401,7 @@ bool MyMoneyStatementReader::import(const MyMoneyStatement& s, TQStringList& mes
   messages += TQString();
 
   // remove the Don't ask again entries
-  KConfig* config = KGlobal::config();
+  TDEConfig* config = TDEGlobal::config();
   config->setGroup(TQString::fromLatin1("Notification Messages"));
   TQStringList::ConstIterator it;
 
@@ -419,7 +419,7 @@ bool MyMoneyStatementReader::import(const MyMoneyStatement& s, TQStringList& mes
   delete m_ft;
   m_ft = 0;
 
-  qDebug("Importing statement for '%s' done", m_account.name().data());
+  tqDebug("Importing statement for '%s' done", m_account.name().data());
 
   return rc;
 }
@@ -501,7 +501,7 @@ void MyMoneyStatementReader::processTransactionEntry(const MyMoneyStatement::Tra
 #if 0
   TQString dbgMsg;
   dbgMsg = TQString("Process %1, '%3', %2").arg(t_in.m_datePosted.toString(Qt::ISODate)).arg(t_in.m_amount.formatMoney("", 2)).arg(t_in.m_strBankID);
-  qDebug("%s", dbgMsg.data());
+  tqDebug("%s", dbgMsg.data());
 #endif
 
   // mark it imported for the view
@@ -958,7 +958,7 @@ void MyMoneyStatementReader::processTransactionEntry(const MyMoneyStatement::Tra
 
         try {
           file->addPayee(payee);
-          qDebug("Payee '%s' created", payee.name().data());
+          tqDebug("Payee '%s' created", payee.name().data());
           d->payees << payee;
           payeeid = payee.id();
           s1.setPayeeId(payeeid);
@@ -1157,7 +1157,7 @@ void MyMoneyStatementReader::processTransactionEntry(const MyMoneyStatement::Tra
               break;
             case TransactionMatcher::matched:
             case TransactionMatcher::matchedExact:
-              qDebug("Detected as match to transaction '%s'", tm.id().data());
+              tqDebug("Detected as match to transaction '%s'", tm.id().data());
               matcher.match(tm, matchedSplit, t, s1, true);
               d->transactionsMatched++;
               break;
@@ -1221,12 +1221,12 @@ void MyMoneyStatementReader::processTransactionEntry(const MyMoneyStatement::Tra
       }
     } else {
       d->transactionsDuplicate++;
-      qDebug("Detected as duplicate");
+      tqDebug("Detected as duplicate");
     }
     delete o;
   } catch (MyMoneyException *e) {
     TQString message(i18n("Problem adding or matching imported transaction with id '%1': %2").arg(t_in.m_strBankID).arg(e->what()));
-    qDebug("%s", message.data());
+    tqDebug("%s", message.data());
     delete e;
 
     int result = KMessageBox::warningContinueCancel(0, message);
@@ -1325,7 +1325,7 @@ bool MyMoneyStatementReader::selectOrCreateAccount(const SelectCreateMode /*mode
           ft.commit();
           accname = account.name();
         } catch(MyMoneyException* e) {
-          qDebug("Updating account in MyMoneyStatementReader::selectOrCreateAccount failed");
+          tqDebug("Updating account in MyMoneyStatementReader::selectOrCreateAccount failed");
           delete e;
         }
       }
