@@ -40,17 +40,17 @@
 // ----------------------------------------------------------------------------
 // KDE Headers
 
-#include <klocale.h>
-#include <kglobal.h>
-#include <kmessagebox.h>
+#include <tdelocale.h>
+#include <tdeglobal.h>
+#include <tdemessagebox.h>
 #include <kcombobox.h>
-#include <klistview.h>
+#include <tdelistview.h>
 #include <kstandarddirs.h>
 #include <kiconloader.h>
 #include <kpushbutton.h>
 #include <kled.h>
 #include <kdebug.h>
-#include <kglobalsettings.h>
+#include <tdeglobalsettings.h>
 
 // ----------------------------------------------------------------------------
 // Project Includes
@@ -345,7 +345,7 @@ KNewAccountDlg::KNewAccountDlg(const MyMoneyAccount& account, bool isEditing, bo
   }
   catch (MyMoneyException *e)
   {
-    qDebug("exception in init for account dialog: %s", e->what().latin1());
+    tqDebug("exception in init for account dialog: %s", e->what().latin1());
     delete e;
   }
 
@@ -362,7 +362,7 @@ KNewAccountDlg::KNewAccountDlg(const MyMoneyAccount& account, bool isEditing, bo
     setCaption(title);
 
   // load button icons
-  KIconLoader* il = KGlobal::iconLoader();
+  TDEIconLoader* il = TDEGlobal::iconLoader();
   cancelButton->setGuiItem(KStdGuiItem::cancel());
   createButton->setGuiItem(KStdGuiItem::ok());
 
@@ -502,7 +502,7 @@ void KNewAccountDlg::okClicked()
       }
       catch (MyMoneyException *e)
       {
-        qDebug("Exception in account institution set: %s", e->what().latin1());
+        tqDebug("Exception in account institution set: %s", e->what().latin1());
         delete e;
       }
     }
@@ -700,7 +700,7 @@ const MyMoneyAccount& KNewAccountDlg::parentAccount(void)
         m_parentAccount = file->equity();
         break;
       default:
-        qDebug("Seems we have an account that hasn't been mapped to the top five");
+        tqDebug("Seems we have an account that hasn't been mapped to the top five");
         if(m_categoryEditor)
           m_parentAccount = file->income();
         else
@@ -916,7 +916,7 @@ void KNewAccountDlg::initParentWidget(TQString parentId, const TQString& account
   }
   catch (MyMoneyException *e)
   {
-    qDebug("Exception in assets account refresh: %s", e->what().latin1());
+    tqDebug("Exception in assets account refresh: %s", e->what().latin1());
     delete e;
   }
 
@@ -974,7 +974,7 @@ void KNewAccountDlg::slotSelectionChanged(TQListViewItem *item)
   {
     MyMoneyFile *file = MyMoneyFile::instance();
 
-    //qDebug("Selected account id: %s", accountItem->accountID().data());
+    //tqDebug("Selected account id: %s", accountItem->accountID().data());
     m_parentAccount = file->account(accountItem->id());
     m_subAccountLabel->setText(i18n("Is a sub account of %1").arg(m_parentAccount.name()));
     if(m_qlistviewParentAccounts->isEnabled()) {
@@ -983,7 +983,7 @@ void KNewAccountDlg::slotSelectionChanged(TQListViewItem *item)
   }
   catch (MyMoneyException *e)
   {
-    qDebug("This shouldn't happen! : %s", e->what().latin1());
+    tqDebug("This shouldn't happen! : %s", e->what().latin1());
     delete e;
   }
 }
@@ -1054,7 +1054,7 @@ void KNewAccountDlg::slotLoadInstitutions(const TQString& name)
   }
   catch (MyMoneyException *e)
   {
-    qDebug("Exception in institution load: %s", e->what().latin1());
+    tqDebug("Exception in institution load: %s", e->what().latin1());
     delete e;
   }
 }
@@ -1109,7 +1109,7 @@ void KNewAccountDlg::slotAccountTypeChanged(const TQString& typeStr)
           parentId = file->income().id();
           break;
         default:
-          qWarning("Unknown account group in KNewAccountDlg::slotAccountTypeChanged()");
+          tqWarning("Unknown account group in KNewAccountDlg::slotAccountTypeChanged()");
           break;
       }
       initParentWidget(parentId, TQString());
@@ -1117,7 +1117,7 @@ void KNewAccountDlg::slotAccountTypeChanged(const TQString& typeStr)
     }
   } catch(MyMoneyException *e) {
     delete e;
-    qWarning("Unexpected exception in KNewAccountDlg::slotAccountTypeChanged()");
+    tqWarning("Unexpected exception in KNewAccountDlg::slotAccountTypeChanged()");
   }
 }
 
