@@ -32,10 +32,10 @@
 // ----------------------------------------------------------------------------
 // KDE Includes
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kpushbutton.h>
 #include <knuminput.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 #include <kiconloader.h>
 #include <kguiitem.h>
 
@@ -118,23 +118,23 @@ KNewLoanWizard::KNewLoanWizard(TQWidget *parent, const char *name ) :
   m_interestAccountEdit->removeButtons();
 
   // load button icons
-  KIconLoader* il = KGlobal::iconLoader();
+  TDEIconLoader* il = TDEGlobal::iconLoader();
   KGuiItem createCategoryButtenItem( i18n( "&Create..." ),
-                      TQIconSet(il->loadIcon("filenew", KIcon::Small, KIcon::SizeSmall)),
+                      TQIconSet(il->loadIcon("document-new", TDEIcon::Small, TDEIcon::SizeSmall)),
                       i18n("Create a new category"),
                       i18n("Use this to open the new account editor"));
   m_createCategoryButton->setGuiItem(createCategoryButtenItem);
   connect(m_createCategoryButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotCreateCategory()));
 
   KGuiItem additionalFeeButtenItem( i18n( "&Additional fees..." ),
-                      0, //TQIconSet(il->loadIcon("filenew", KIcon::Small, KIcon::SizeSmall)),
+                      0, //TQIconSet(il->loadIcon("document-new", TDEIcon::Small, TDEIcon::SizeSmall)),
                       i18n("Enter additional fees"),
                       i18n("Use this to add any additional fees other than principal and interest contained in your periodical payments."));
   m_additionalFeeButton->setGuiItem(additionalFeeButtenItem);
   connect(m_additionalFeeButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotAdditionalFees()));
 
   KGuiItem createAssetButtenItem( i18n( "&Create..." ),
-                      TQIconSet(il->loadIcon("filenew", KIcon::Small, KIcon::SizeSmall)),
+                      TQIconSet(il->loadIcon("document-new", TDEIcon::Small, TDEIcon::SizeSmall)),
                       i18n("Create a new asset account"),
                       i18n("Use this to create a new account to which the initial payment should be made"));
   m_createNewAssetButton->setGuiItem(createAssetButtenItem);
@@ -418,7 +418,7 @@ void KNewLoanWizard::updateSummary(void)
   else
     m_summaryLoanType->setText(i18n("lend"));
 
-  m_summaryFirstPayment->setText(KGlobal::locale()->formatDate(m_firstDueDateEdit->date(), true));
+  m_summaryFirstPayment->setText(TDEGlobal::locale()->formatDate(m_firstDueDateEdit->date(), true));
   if(m_payeeEdit->selectedItem().isEmpty()) {
     m_summaryPayee->setText(i18n("not assigned"));
   } else {
@@ -445,12 +445,12 @@ void KNewLoanWizard::updateSummary(void)
     MyMoneyAccount acc = MyMoneyFile::instance()->account(sel.first());
     m_summaryInterestCategory->setText(acc.name());
   } catch(MyMoneyException *e) {
-    qWarning("Unable to determine interest category for loan account creation");
+    tqWarning("Unable to determine interest category for loan account creation");
     delete e;
   }
   m_summaryAdditionalFees->setText(m_additionalCost->text());
   m_summaryTotalPeriodicPayment->setText(m_periodicPayment->text());
-  m_summaryNextPayment->setText(KGlobal::locale()->formatDate(m_nextDueDateEdit->date(), true));
+  m_summaryNextPayment->setText(TDEGlobal::locale()->formatDate(m_nextDueDateEdit->date(), true));
 
   try {
     TQStringList sel = m_paymentAccountEdit->selectedItems();
@@ -459,7 +459,7 @@ void KNewLoanWizard::updateSummary(void)
     MyMoneyAccount acc = MyMoneyFile::instance()->account(sel.first());
     m_summaryPaymentAccount->setText(acc.name());
   } catch(MyMoneyException *e) {
-    qWarning("Unable to determine payment account for loan account creation");
+    tqWarning("Unable to determine payment account for loan account creation");
     delete e;
   }
 }
@@ -789,7 +789,7 @@ int KNewLoanWizard::calculateLoan(void)
       if((m_borrowButton->isChecked() && val < 0 && fabsl(val) > fabsl(calc.payment()))
       || (m_lendButton->isChecked() && val > 0 && fabs(val) > fabs(calc.payment()))) {
         // case a)
-        qDebug("Future Value is %Lf", val);
+        tqDebug("Future Value is %Lf", val);
         throw new MYMONEYEXCEPTION("incorrect fincancial calculation");
 
       } else if((m_borrowButton->isChecked() && val < 0 && fabsl(val) <= fabsl(calc.payment()))
