@@ -272,7 +272,7 @@ bool MyMoneyTransactionFilter::match(const MyMoneyTransaction& transaction)
 
   m_matchingSplits.clear();
 
-  // qDebug("T: %s", transaction.id().data());
+  // tqDebug("T: %s", transaction.id().data());
   // if no filter is set, we can savely return a match
   // if we should report all splits, then we collect them
   if(!m_filterSet.allFilter) {
@@ -372,7 +372,7 @@ bool MyMoneyTransactionFilter::match(const MyMoneyTransaction& transaction)
 
       sp = matchingSplits.next();
       if(removeSplit) {
-        // qDebug(" S: %s", (*it).id().data());
+        // tqDebug(" S: %s", (*it).id().data());
         matchingSplits.remove(removeSplit);
       }
     }
@@ -460,7 +460,7 @@ bool MyMoneyTransactionFilter::match(const MyMoneyTransaction& transaction)
 
       sp = matchingSplits.next();
       if(removeSplit) {
-        // qDebug(" S: %s", (*it).id().data());
+        // tqDebug(" S: %s", (*it).id().data());
         matchingSplits.remove(removeSplit);
       }
     }
@@ -474,7 +474,7 @@ bool MyMoneyTransactionFilter::match(const MyMoneyTransaction& transaction)
     }
   }
   // all filters passed, I guess we have a match
-  // qDebug("  C: %d", m_matchingSplits.count());
+  // tqDebug("  C: %d", m_matchingSplits.count());
   return matchingSplits.count() != 0;
 }
 
@@ -835,7 +835,7 @@ bool MyMoneyTransactionFilter::translateDateRange(dateOptionE id, TQDate& start,
       end =  TQDate::currentDate();
       break;
     default:
-      qFatal("Unknown date identifier %d in MyMoneyTransactionFilter::translateDateRange()", id);
+      tqFatal("Unknown date identifier %d in MyMoneyTransactionFilter::translateDateRange()", id);
       rc = false;
       break;
   }
@@ -845,13 +845,13 @@ bool MyMoneyTransactionFilter::translateDateRange(dateOptionE id, TQDate& start,
 void MyMoneyTransactionFilter::removeReference(const TQString& id)
 {
   if(m_accounts.find(id)) {
-    qDebug("%s", (TQString("Remove account '%1' from report").arg(id)).data());
+    tqDebug("%s", (TQString("Remove account '%1' from report").arg(id)).data());
     m_accounts.remove(id);
   } else if(m_categories.find(id)) {
-    qDebug("%s", (TQString("Remove category '%1' from report").arg(id)).data());
+    tqDebug("%s", (TQString("Remove category '%1' from report").arg(id)).data());
     m_categories.remove(id);
   } else if(m_payees.find(id)) {
-    qDebug("%s", (TQString("Remove payee '%1' from report").arg(id)).data());
+    tqDebug("%s", (TQString("Remove payee '%1' from report").arg(id)).data());
     m_payees.remove(id);
   }
 }
