@@ -110,7 +110,7 @@ MyMoneySeqAccessMgr const * MyMoneySeqAccessMgr::duplicate(void)
   /**
  * This method is used to get a SQL reader for subsequent database access
    */
-KSharedPtr <MyMoneyStorageSql> MyMoneySeqAccessMgr::connectToDatabase
+TDESharedPtr <MyMoneyStorageSql> MyMoneySeqAccessMgr::connectToDatabase
       (const KURL& /*url*/) {
   return 0;
 }
@@ -870,7 +870,7 @@ const MyMoneyMoney MyMoneySeqAccessMgr::balance(const TQString& id, const TQDate
 {
   MyMoneyMoney result(0);
   MyMoneyAccount acc;
-  // if (date != TQDate()) qDebug ("request balance for %s at %s", id.data(), date.toString(Qt::ISODate).latin1());
+  // if (date != TQDate()) tqDebug ("request balance for %s at %s", id.data(), date.toString(Qt::ISODate).latin1());
   if(!date.isValid() && account(id).accountType() != MyMoneyAccount::Stock) {
     if(m_accountList.find(id) != m_accountList.end())
       return m_accountList[id].balance();
@@ -923,7 +923,7 @@ const MyMoneyMoney MyMoneySeqAccessMgr::balance(const TQString& id, const TQDate
   if(m_balanceCache[id].valid == true)
     result = m_balanceCache[id].balance;
   else
-    qDebug("Cache mishit should never happen at this point");
+    tqDebug("Cache mishit should never happen at this point");
 
   return result;
 }
@@ -1245,10 +1245,10 @@ const TQValueList<MyMoneySchedule> MyMoneySeqAccessMgr::scheduleList(
   TQMap<TQString, MyMoneySchedule>::ConstIterator pos;
   TQValueList<MyMoneySchedule> list;
 
-  // qDebug("scheduleList()");
+  // tqDebug("scheduleList()");
 
   for(pos = m_scheduleList.begin(); pos != m_scheduleList.end(); ++pos) {
-    // qDebug("  '%s'", qPrintable((*pos).id()));
+    // tqDebug("  '%s'", qPrintable((*pos).id()));
 
     if(type != MyMoneySchedule::TYPE_ANY) {
       if(type != (*pos).type()) {
@@ -1305,7 +1305,7 @@ const TQValueList<MyMoneySchedule> MyMoneySeqAccessMgr::scheduleList(
         continue;
     }
 
-    // qDebug("Adding '%s'", (*pos).name().latin1());
+    // tqDebug("Adding '%s'", (*pos).name().latin1());
     list << *pos;
   }
   return list;
@@ -1340,7 +1340,7 @@ const TQValueList<MyMoneySchedule> MyMoneySeqAccessMgr::scheduleListEx(int sched
                                                                 TQDate date,
                                                                 const TQStringList& accounts) const
 {
-//  qDebug("scheduleListEx");
+//  tqDebug("scheduleListEx");
 
   TQMap<TQString, MyMoneySchedule>::ConstIterator pos;
   TQValueList<MyMoneySchedule> list;
@@ -1374,7 +1374,7 @@ const TQValueList<MyMoneySchedule> MyMoneySeqAccessMgr::scheduleListEx(int sched
         continue;
     }
 
-//    qDebug("\tAdding '%s'", (*pos).name().latin1());
+//    tqDebug("\tAdding '%s'", (*pos).name().latin1());
     list << *pos;
   }
 
@@ -1436,7 +1436,7 @@ const MyMoneySecurity MyMoneySeqAccessMgr::security(const TQString& id) const
 
 const TQValueList<MyMoneySecurity> MyMoneySeqAccessMgr::securityList(void) const
 {
-  //qDebug("securityList: Security list size is %d, this=%8p", m_equitiesList.size(), (void*)this);
+  //tqDebug("securityList: Security list size is %d, this=%8p", m_equitiesList.size(), (void*)this);
   return m_securitiesList.values();
 }
 
