@@ -45,15 +45,15 @@
 // ----------------------------------------------------------------------------
 // KDE Includes
 
-#include <kglobal.h>
-#include <klocale.h>
-#include <kmessagebox.h>
+#include <tdeglobal.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
 #include <kpushbutton.h>
 #include <kiconloader.h>
 #include <kguiitem.h>
 #include <kstandarddirs.h>
 #include <kdebug.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <keditlistbox.h>
 
 // ----------------------------------------------------------------------------
@@ -62,7 +62,7 @@
 #include <kmymoney/mymoneyfile.h>
 #include <kmymoney/kmymoneyaccounttree.h>
 #include <kmymoney/kmymoneyglobalsettings.h>
-#include "../widgets/klistviewsearchline.h"
+#include "../widgets/tdelistviewsearchline.h"
 
 #include "kpayeesview.h"
 
@@ -260,8 +260,8 @@ void KTransactionPtrVector::setPayeeId(const TQString& id)
 
 // *** KPayeeListItem Implementation ***
 
-KPayeeListItem::KPayeeListItem(KListView *parent, const MyMoneyPayee& payee) :
-  KListViewItem(parent),
+KPayeeListItem::KPayeeListItem(TDEListView *parent, const MyMoneyPayee& payee) :
+  TDEListViewItem(parent),
   m_payee(payee)
 {
   setText(0, payee.name());
@@ -287,8 +287,8 @@ void KPayeeListItem::paintCell(TQPainter *p, const TQColorGroup & cg, int column
   TQListViewItem::paintCell(p, cg2, column, width, align);
 }
 
-KTransactionListItem::KTransactionListItem(KListView* view, KTransactionListItem* parent, const TQString& accountId, const TQString& transactionId) :
-  KListViewItem(view, parent)
+KTransactionListItem::KTransactionListItem(TDEListView* view, KTransactionListItem* parent, const TQString& accountId, const TQString& transactionId) :
+  TDEListViewItem(view, parent)
 {
   m_accountId = accountId;
   m_transactionId = transactionId;
@@ -324,7 +324,7 @@ KPayeesView::KPayeesView(TQWidget *parent, const char *name ) :
 {
   // create the searchline widget
   // and insert it into the existing layout
-  m_searchWidget = new KListViewSearchLineWidget(m_payeesList, this);
+  m_searchWidget = new TDEListViewSearchLineWidget(m_payeesList, this);
   m_searchWidget->setSizePolicy(TQSizePolicy(TQSizePolicy::Preferred, TQSizePolicy::Fixed));
   KPayeesViewDeclLayout->insertWidget(0, m_searchWidget);
 
@@ -336,7 +336,7 @@ KPayeesView::KPayeesView(TQWidget *parent, const char *name ) :
   layout10->addWidget(m_splitter);
 
   // use the size settings of the last run (if any)
-  KConfig *config = KGlobal::config();
+  TDEConfig *config = TDEGlobal::config();
   config->setGroup("Last Use Settings");
   TQValueList<int> sizes = config->readIntListEntry("KPayeesViewSplitterSize");
   if(sizes.size() == 2) {
@@ -364,9 +364,9 @@ KPayeesView::KPayeesView(TQWidget *parent, const char *name ) :
   labelDefaultAccount->setEnabled(false);
   comboDefaultAccount->setEnabled(false);
 
-  KIconLoader* il = KGlobal::iconLoader();
+  TDEIconLoader* il = TDEGlobal::iconLoader();
   KGuiItem updateButtenItem( i18n("Update"),
-                    TQIconSet(il->loadIcon("button_ok", KIcon::Small, KIcon::SizeSmall)),
+                    TQIconSet(il->loadIcon("button_ok", TDEIcon::Small, TDEIcon::SizeSmall)),
                     i18n("Accepts the entered data and stores it"),
                     i18n("Use this to accept the modified data."));
   m_updateButton->setGuiItem(updateButtenItem);
@@ -393,7 +393,7 @@ KPayeesView::KPayeesView(TQWidget *parent, const char *name ) :
   connect(m_updateButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotUpdatePayee()));
   connect(m_helpButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotHelp()));
 
-  connect(m_payeesList, TQT_SIGNAL(contextMenu(KListView*, TQListViewItem*, const TQPoint&)), this, TQT_SLOT(slotOpenContextMenu(KListView*, TQListViewItem*, const TQPoint&)));
+  connect(m_payeesList, TQT_SIGNAL(contextMenu(TDEListView*, TQListViewItem*, const TQPoint&)), this, TQT_SLOT(slotOpenContextMenu(TDEListView*, TQListViewItem*, const TQPoint&)));
 
 //  connect(m_payeesList, TQT_SIGNAL(rightButtonClicked(TQListViewItem* , const TQPoint&, int)),
 //    this, TQT_SLOT(slotOpenContextMenu(TQListViewItem*)));
@@ -409,7 +409,7 @@ KPayeesView::KPayeesView(TQWidget *parent, const char *name ) :
 KPayeesView::~KPayeesView()
 {
   // remember the splitter settings for startup
-  KConfig *config = KGlobal::config();
+  TDEConfig *config = TDEGlobal::config();
   config->setGroup("Last Use Settings");
   config->writeEntry("KPayeesViewSplitterSize", m_splitter->sizes());
 }
@@ -417,7 +417,7 @@ KPayeesView::~KPayeesView()
 void KPayeesView::slotQueueUpdate(void)
 {
   m_updatesQueued++;
-  // The KListViewSearchLineWidget has an internal timer for update purposes
+  // The TDEListViewSearchLineWidget has an internal timer for update purposes
   // of 200 ms, so we should be safe with 250 ms here
   TQTimer::singleShot(250, this, TQT_SLOT(slotActivateUpdate()));
 }
@@ -637,7 +637,7 @@ void KPayeesView::slotSelectPayee(void)
     showTransactions();
 
   } catch(MyMoneyException *e) {
-    qDebug("exception during display of payee: %s at %s:%ld", e->what().latin1(), e->file().latin1(), e->line());
+    tqDebug("exception during display of payee: %s at %s:%ld", e->what().latin1(), e->file().latin1(), e->line());
     m_transactionView->clear();
     m_payee = MyMoneyPayee();
     delete e;
@@ -721,7 +721,7 @@ void KPayeesView::showTransactions(void)
 
     item = new KTransactionListItem(m_transactionView, item, s.accountId(), t->id());
     item->setText(0, s.number());
-    item->setText(1, KGlobal::locale()->formatDate(t->postDate(), true));
+    item->setText(1, TDEGlobal::locale()->formatDate(t->postDate(), true));
 
     TQString txt;
     if(s.action() == MyMoneySplit::ActionAmortization) {
@@ -900,8 +900,8 @@ void KPayeesView::readConfig(void)
 void KPayeesView::show(void)
 {
   // since we could not construct the connection in our own ctor,
-  // we set it up now. The widgets of the KListViewSearchLineWidget must exist by now.
-  // If you want to learn about the details, see the source of KListViewSearchLineWidget's
+  // we set it up now. The widgets of the TDEListViewSearchLineWidget must exist by now.
+  // If you want to learn about the details, see the source of TDEListViewSearchLineWidget's
   // constructor
   if(m_needConnection) {
     connect(m_searchWidget->searchLine(), TQT_SIGNAL(textChanged(const TQString&)), this, TQT_SLOT(slotQueueUpdate(void)));
@@ -1083,12 +1083,12 @@ void KPayeesView::slotSelectPayeeAndTransaction(const TQString& payeeId, const T
     }
 
   } catch(MyMoneyException *e) {
-    qWarning("Unexpected exception in KPayeesView::slotSelectPayeeAndTransaction");
+    tqWarning("Unexpected exception in KPayeesView::slotSelectPayeeAndTransaction");
     delete e;
   }
 }
 
-void KPayeesView::slotOpenContextMenu(KListView* lv, TQListViewItem* i, const TQPoint& p)
+void KPayeesView::slotOpenContextMenu(TDEListView* lv, TQListViewItem* i, const TQPoint& p)
 {
   Q_UNUSED(p);
   if(lv == m_payeesList) {
